@@ -392,7 +392,7 @@ iesys_handle_to_tpm_handle(ESYS_TR esys_handle, TPM2_HANDLE * tpm_handle)
         *tpm_handle = TPM2_NV_AC_FIRST + (esys_handle - ESYS_TR_RH_AC_FIRST);
         return TPM2_RC_SUCCESS;
     }
-    LOG_ERROR("Error: Esys invalid ESAPI handle (%x).", esys_handle);
+    LOG_ERROR("Error: Esys invalid ESAPI handle (%"PRIx32").", esys_handle);
     return TSS2_ESYS_RC_BAD_VALUE;
 }
 
@@ -413,7 +413,7 @@ iesys_is_platform_handle(ESYS_TR handle) {
     case TPM2_RH_PLATFORM_NV:
     case TPM2_RH_ENDORSEMENT:
     case TPM2_RH_NULL:
-        LOG_WARNING("Convert handle from TPM2_RH to ESYS_TR, got: 0x%x",
+        LOG_WARNING("Convert handle from TPM2_RH to ESYS_TR, got: 0x%"PRIx32,
                 handle);
         return true;
     default:
@@ -574,7 +574,7 @@ iesys_gen_caller_nonces(ESYS_CONTEXT * esys_context)
         r = iesys_crypto_get_random2b(&esys_context->crypto_backend,
                 &session->rsrc.misc.rsrc_session.nonceCaller,
                 session->rsrc.misc.rsrc_session.nonceCaller.size);
-        return_if_error(r, "Error: computing caller nonce (%x).");
+        return_if_error(r, "Error: computing caller nonce.");
     }
     return TSS2_RC_SUCCESS;
 }
@@ -612,7 +612,7 @@ iesys_update_session_flags(ESYS_CONTEXT * esys_context,
         rsrc_session->sessionAttributes &= ~(TPMA_SESSION_ENCRYPT);
     }
 
-    LOG_DEBUG("Session Attrs 0x%x orig 0x%x",
+    LOG_DEBUG("Session Attrs 0x%"PRIx32" orig 0x%"PRIx32,
 	      rsrc_session->sessionAttributes,
 	      rsrc_session->origSessionAttributes);
 }
@@ -633,7 +633,7 @@ iesys_restore_session_flags(ESYS_CONTEXT *esys_context)
         if (session == NULL)
             continue;
         IESYS_SESSION *rsrc_session = &session->rsrc.misc.rsrc_session;
-        LOG_DEBUG("Orig Session %i Attrs 0x%x, altered Attrs x%x", i,
+        LOG_DEBUG("Orig Session %i Attrs 0x%"PRIx8", altered Attrs x%"PRIx8, i,
                   rsrc_session->origSessionAttributes,
                   rsrc_session->sessionAttributes);
 
@@ -1104,7 +1104,7 @@ esys_GetResourceObject(ESYS_CONTEXT * esys_context,
     /* All objects with a TR-handle larger than ESYS_TR_MIN_OBJECT must have
        been initialized previously. Therefore the TR handle was erroneous. */
     if (esys_handle >= ESYS_TR_MIN_OBJECT) {
-        LOG_ERROR("Error: Esys handle does not exist (%x).",
+        LOG_ERROR("Error: Esys handle does not exist (0x%08"PRIx32").",
                   TSS2_ESYS_RC_BAD_TR);
         return TSS2_ESYS_RC_BAD_TR;
     }
@@ -1591,11 +1591,28 @@ iesys_tpm_error(TSS2_RC r)
              (r & TSS2_RC_LAYER_MASK) == TSS2_RESMGR_RC_LAYER));
 }
 
+/** Remove trailing spaces includes auth value.
+ *
+ * Trailing zeros will be removed.
+ *
+ * @param[in,out] auth_value The auth value to be adapted.
+ */
+void iesys_strip_trailing_zeros(TPM2B_DIGEST *digest)
+{
+    /* Remove trailing zeroes */
+    if (digest) {
+        while (digest->size > 0 &&
+               digest->buffer[digest->size - 1] == 0) {
+            digest->size--;
+        }
+    }
+}
 
-/** Replace auth value with Hash for long auth values.
+/** Adapt auth value.
  *
  * if the size of auth value exceeds hash_size the auth value
  * will be replaced with the hash of the auth value.
+ * Trailing zeros will be removed.
  *
  * @param[in,out] auth_value The auth value to be adapted.
  * @param[in] hash_alg The hash alg used for adaption.
@@ -1606,37 +1623,46 @@ iesys_tpm_error(TSS2_RC r)
  *         computation.
  */
 TSS2_RC
-iesys_hash_long_auth_values(
+iesys_adapt_auth_value(
     ESYS_CRYPTO_CALLBACKS *crypto_cb,
     TPM2B_AUTH *auth_value,
     TPMI_ALG_HASH hash_alg)
 {
-    TSS2_RC r;
+    TSS2_RC r = TSS2_RC_SUCCESS;
     ESYS_CRYPTO_CONTEXT_BLOB *cryptoContext;
     TPM2B_AUTH hash2b;
     size_t hash_size;
 
-    r = iesys_crypto_hash_get_digest_size(hash_alg, &hash_size);
-    return_if_error(r, "Get digest size.");
+    /* Remove trailing zeroes */
+    iesys_strip_trailing_zeros(auth_value);
 
-    if (auth_value && auth_value->size > hash_size) {
-        /* The auth value has to be adapted. */
-        r = iesys_crypto_hash_start(crypto_cb,
-                &cryptoContext, hash_alg);
-        return_if_error(r, "crypto hash start");
+    if (hash_alg) {
+        r = iesys_crypto_hash_get_digest_size(hash_alg, &hash_size);
+        return_if_error(r, "Get digest size.");
 
-        r = iesys_crypto_hash_update(crypto_cb,
-                cryptoContext, &auth_value->buffer[0],
-                auth_value->size);
-        goto_if_error(r, "crypto hash update", error_cleanup);
+        if (auth_value && auth_value->size > hash_size) {
+            /* The auth value has to be adapted. */
+            r = iesys_crypto_hash_start(crypto_cb,
+                     &cryptoContext, hash_alg);
+            return_if_error(r, "crypto hash start");
 
-        r = iesys_crypto_hash_finish(crypto_cb,
-                &cryptoContext, &hash2b.buffer[0], &hash_size);
-        goto_if_error(r, "crypto hash finish", error_cleanup);
+            r = iesys_crypto_hash_update(crypto_cb,
+                    cryptoContext, &auth_value->buffer[0],
+                    auth_value->size);
+            goto_if_error(r, "crypto hash update", error_cleanup);
 
-        memcpy(&auth_value->buffer[0], &hash2b.buffer[0], hash_size);
-        auth_value->size = hash_size;
+            r = iesys_crypto_hash_finish(crypto_cb,
+                    &cryptoContext, &hash2b.buffer[0], &hash_size);
+            goto_if_error(r, "crypto hash finish", error_cleanup);
+
+            memcpy(&auth_value->buffer[0], &hash2b.buffer[0], hash_size);
+            auth_value->size = hash_size;
+
+            /* Remove trailing zeroes */
+            iesys_strip_trailing_zeros(auth_value);
+        }
     }
+
     return r;
 
  error_cleanup:
