@@ -399,7 +399,7 @@ Fapi_CreateNv_Finish(
             context->primary_state = PRIMARY_INIT;
             r = ifapi_get_sessions_async(context,
                                          IFAPI_SESSION_GENEK | IFAPI_SESSION1,
-                                         0, 0);
+                                         TPMA_SESSION_DECRYPT, 0);
             goto_if_error_reset_state(r, "Create sessions", error_cleanup);
             fallthrough;
 
@@ -421,7 +421,7 @@ Fapi_CreateNv_Finish(
             r = Esys_NV_DefineSpace_Async(context->esys,
                                           hierarchy->public.handle,
                                           auth_session,
-                                          ESYS_TR_NONE,
+                                          ENC_SESSION_IF_POLICY(auth_session),
                                           ESYS_TR_NONE,
                                           auth,
                                           publicInfo);
