@@ -427,7 +427,8 @@ Fapi_Import_Finish(
 
             r = Esys_Load_Async(context->esys, context->loadKey.handle,
                                 auth_session,
-                                ESYS_TR_NONE, ESYS_TR_NONE,
+                                ENC_SESSION_IF_POLICY(auth_session),
+                                ESYS_TR_NONE,
                                 &private, &object->misc.key.public);
             goto_if_error(r, "Load async", error_cleanup);
             fallthrough;
@@ -534,7 +535,8 @@ Fapi_Import_Finish(
             r = Esys_Import_Async(context->esys,
                   command->parent_object->public.handle,
                   session,
-                  ESYS_TR_NONE, ESYS_TR_NONE,
+                  ENC_SESSION_IF_POLICY(session),
+                  ESYS_TR_NONE,
                   NULL, &keyTree->public,
                   &keyTree->duplicate,
                   &keyTree->encrypted_seed,
@@ -564,6 +566,8 @@ Fapi_Import_Finish(
             if (!command->parent_object->misc.key.persistent_handle) {
                 r = ifapi_flush_object(context, command->parent_object->public.handle);
                 return_try_again(r);
+
+                command->parent_object->public.handle = ESYS_TR_NONE;
                 ifapi_cleanup_ifapi_object(command->parent_object);
                 goto_if_error(r, "Flush key", error_cleanup);
             } else {
@@ -666,5 +670,6 @@ error_cleanup:
     ifapi_cleanup_ifapi_object(&context->loadKey.auth_object);
     ifapi_cleanup_ifapi_object(context->loadKey.key_object);
     ifapi_cleanup_ifapi_object(&context->createPrimary.pkey_object);
+    context->state = _FAPI_STATE_INIT;
     return r;
 }
