@@ -349,7 +349,7 @@ Fapi_NvExtend_Finish(
                                  command->auth_index,
                                  nvIndex,
                                  auth_session,
-                                 ESYS_TR_NONE,
+                                 ENC_SESSION_IF_POLICY(auth_session),
                                  ESYS_TR_NONE,
                                  auxData);
         goto_if_error_reset_state(r, " Fapi_NvExtend_Async", error_cleanup);
@@ -370,7 +370,7 @@ Fapi_NvExtend_Finish(
         /* Compute Digest of the current event */
         hashAlg = object->misc.nv.public.nvPublic.nameAlg;
         r = ifapi_crypto_hash_start(&cryptoContext, hashAlg);
-        return_if_error(r, "crypto hash start");
+        goto_if_error(r, "crypto hash start", error_cleanup);
 
         HASH_UPDATE_BUFFER(cryptoContext,
                            &auxData->buffer[0], auxData->size,
@@ -380,7 +380,7 @@ Fapi_NvExtend_Finish(
                                      (uint8_t *)
                                      &event->digests.digests[0].digest,
                                      &hashSize);
-        return_if_error(r, "crypto hash finish");
+        goto_if_error(r, "crypto hash finish", error_cleanup);
 
         event->digests.digests[0].hashAlg = hashAlg;
         event->digests.count = 1;
@@ -448,7 +448,7 @@ Fapi_NvExtend_Finish(
         /* Finish writing the NV object to the key store */
         r = ifapi_keystore_store_finish(&context->io);
         return_try_again(r);
-        return_if_error_reset_state(r, "write_finish failed");
+        goto_if_error(r, "write_finish failed", error_cleanup);
         fallthrough;
 
     statecase(context->state, NV_EXTEND_CLEANUP)
@@ -456,7 +456,6 @@ Fapi_NvExtend_Finish(
         r = ifapi_cleanup_session(context);
         try_again_or_error_goto(r, "Cleanup", error_cleanup);
 
-        context->state = _FAPI_STATE_INIT;
         r = TSS2_RC_SUCCESS;
 
         break;
@@ -483,5 +482,6 @@ error_cleanup:
     SAFE_FREE(object->misc.nv.event_log);
     ifapi_session_clean(context);
     LOG_TRACE("finished");
+    context->state = _FAPI_STATE_INIT;
     return r;
 }
