@@ -924,7 +924,8 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
             }
             r = ifapi_io_read_async(&context->io, int_ca_file);
             return_try_again(r);
-            goto_if_error2(r, "Reading certificate %s", error_cleanup, int_ca_file);
+            goto_if_error2(r, "Reading certificate %s", error_cleanup,
+                           getenv("FAPI_TEST_INT_CERT"));
 
 	        fallthrough;
 
@@ -980,7 +981,8 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
         statecase(context->state, PROVISION_INIT_SRK);
             /* Create session which will be used for SRK generation. */
             context->srk_handle = context->ek_handle;
-            r = ifapi_get_sessions_async(context, IFAPI_SESSION1, 0, 0);
+            r = ifapi_get_sessions_async(context, IFAPI_SESSION_USE_SRK | IFAPI_SESSION1,
+                                         TPMA_SESSION_DECRYPT, 0);
             goto_if_error_reset_state(r, "Create sessions", error_cleanup);
 
             fallthrough;
@@ -1001,9 +1003,9 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
                 if (command->auth_state & TPMA_PERMANENT_LOCKOUTAUTHSET) {
                     hierarchy_lockout->misc.hierarchy.with_auth = TPM2_YES;
                     r = ifapi_get_description(hierarchy_lockout, &description);
-                    return_if_error(r, "Get description");
+                    goto_if_error(r, "Get description", error_cleanup);
                     r = ifapi_set_auth(context, hierarchy_lockout, description);
-                    return_if_error(r, "Set auth value");
+                    goto_if_error(r, "Set auth value", error_cleanup);
                 } else {
                     hierarchy_lockout->misc.hierarchy.with_auth = TPM2_NO;
                 }
@@ -1021,7 +1023,9 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
 
             /* Prepare the setting of the dictionary attack parameters. */
             r = Esys_DictionaryAttackParameters_Async(context->esys, ESYS_TR_RH_LOCKOUT,
-                       auth_session, ESYS_TR_NONE, ESYS_TR_NONE,
+                       auth_session,
+                       ESYS_TR_NONE,
+                       ESYS_TR_NONE,
                        defaultProfile->newMaxTries, defaultProfile->newRecoveryTime,
                        defaultProfile->lockoutRecovery);
             goto_if_error(r, "Error Esys_DictionaryAttackParameters",
@@ -1180,7 +1184,8 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
             try_again_or_error_goto(r, "Cleanup", error_cleanup);
 
             /* Create session which will be used for parameter encryption. */
-            r = ifapi_get_sessions_async(context, IFAPI_SESSION1, 0, 0);
+            r = ifapi_get_sessions_async(context, IFAPI_SESSION_USE_SRK | IFAPI_SESSION1,
+                                         TPMA_SESSION_DECRYPT, 0);
             goto_if_error_reset_state(r, "Create sessions", error_cleanup);
 
             fallthrough;
@@ -1362,7 +1367,7 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
             /* Finish writing the endorsement hierarchy to the key store */
             r = ifapi_keystore_store_finish(&context->io);
             return_try_again(r);
-            return_if_error_reset_state(r, "write_finish failed");
+            goto_if_error_reset_state(r, "write_finish failed", error_cleanup);
 
             /* Write all endorsement hierarchies. */
             command->hierarchy = hierarchy_he;
@@ -1634,6 +1639,7 @@ error_cleanup:
         }
         SAFE_FREE(command->pathlist);
     }
+    context->state = _FAPI_STATE_INIT;
     LOG_TRACE("finished");
     return r;
 }
