@@ -244,7 +244,8 @@ Fapi_Unseal_Finish(
             /* Perform the unseal operation with the TPM. */
             r = Esys_Unseal_Async(context->esys, command->object->public.handle,
                     auth_session,
-                    ESYS_TR_NONE, ESYS_TR_NONE);
+                    ENC_SESSION_IF_POLICY(auth_session),
+                    ESYS_TR_NONE);
             goto_if_error(r, "Error esys Unseal ", error_cleanup);
 
             fallthrough;
@@ -289,7 +290,6 @@ Fapi_Unseal_Finish(
             }
             SAFE_FREE(command->unseal_data);
 
-            context->state = _FAPI_STATE_INIT;
             break;
 
         statecasedefault(context->state);
@@ -305,6 +305,7 @@ error_cleanup:
     ifapi_cleanup_ifapi_object(&context->createPrimary.pkey_object);
     ifapi_session_clean(context);
     SAFE_FREE(command->keyPath);
+    context->state = _FAPI_STATE_INIT;
     LOG_TRACE("finished");
     return r;
 }
