@@ -55,9 +55,10 @@ typedef UINT32 TSS2_KEY_TYPE;
 #define MAX_PLATFORM_CERT_HANDLE 0x01C0FFFF
 
 typedef UINT8 IFAPI_SESSION_TYPE;
-#define IFAPI_SESSION_GENEK 0x01
-#define IFAPI_SESSION1      0x02
-#define IFAPI_SESSION2      0x04
+#define IFAPI_SESSION_GENEK   0x01
+#define IFAPI_SESSION1        0x02
+#define IFAPI_SESSION2        0x04
+#define IFAPI_SESSION_USE_SRK 0x08
 
 #define IFAPI_POLICY_PATH "policy"
 #define IFAPI_NV_PATH "nv"
@@ -126,6 +127,11 @@ typedef struct {
         goto label;  \
     }
 
+#define ENC_SESSION_IF_POLICY(auth_session)             \
+    (auth_session == ESYS_TR_PASSWORD || auth_session == ESYS_TR_NONE || \
+     auth_session == context->session2 || \
+     !context->session2) ? ESYS_TR_NONE : context->session2
+
 /** The states for the FAPI's object authorization state*/
 enum IFAPI_GET_CERT_STATE {
     GET_CERT_INIT = 0,
@@ -185,13 +191,6 @@ typedef struct {
     TPMS_NV_PUBLIC                               public;    /**< Template for public data */
 } IFAPI_NV_TEMPLATE;
 
-/** Type for representing a external public key
- */
-typedef struct {
-    TPMT_SIG_SCHEME                          sig_scheme;    /**< Signature scheme used for quote. */
-    TPMS_ATTEST                                  attest;    /**< Attestation data from Quote */
-} FAPI_QUOTE_INFO;
-
 
 /** The states for the FAPI's NV read state */
 enum _FAPI_STATE_NV_READ {
@@ -239,6 +238,7 @@ typedef struct {
     TPM2B_AUTH auth;            /**< The Password */
     IFAPI_NV nv_obj;            /**< The NV Object */
     ESYS_TR auth_index;         /**< The ESAPI handle of the authorization object */
+    ESYS_TR auth_session;       /**< The autorization session for a nv object */
     uint64_t bitmap;            /**< The bitmask for the SetBits command */
     IFAPI_NV_TEMPLATE public_templ; /**< The template for nv creation, adjusted
                                          appropriate by the passed flags */
@@ -291,7 +291,8 @@ typedef struct {
     uint32_t const *hashAlgs;
     uint32_t *hashAlgs2;
     size_t numHashAlgs;
-    char    const *quoteInfo;
+    char const *quoteInfo;
+    char *certificate;
     TPM2B_ATTEST *tpm_quoted;
     TPMT_SIGNATURE *tpm_signature;
     uint8_t *signature;
