@@ -155,12 +155,12 @@ static void spi_tpm_helper_log_register_access(enum TCTI_SPI_HELPER_REGISTER_ACC
     char* access_str = (access == TCTI_SPI_HELPER_REGISTER_READ) ? "READ" : "WRITE";
 
     if (err != NULL) {
-        LOG_ERROR("%s register %#02x (%zu bytes) %s", access_str, reg_number, cnt, err);
+        LOG_ERROR("%s register %#02"PRIx32" (%zu bytes) %s", access_str, reg_number, cnt, err);
     } else {
 #if MAXLOGLEVEL < LOGL_TRACE
         (void) buffer;
 #else
-        LOGBLOB_TRACE(buffer, cnt, "%s register %#02x (%zu bytes)", access_str, reg_number, cnt);
+        LOGBLOB_TRACE(buffer, cnt, "%s register %#02"PRIx32" (%zu bytes)", access_str, reg_number, cnt);
 #endif
     }
 #endif
@@ -545,7 +545,7 @@ TSS2_RC tcti_spi_helper_receive (TSS2_TCTI_CONTEXT* tcti_context, size_t *respon
     // Verify that there is still data to read
     uint32_t status = spi_tpm_helper_read_sts_reg(ctx);
     if ((status & expected_status_bits) != expected_status_bits) {
-        LOG_ERROR("Unexpected intermediate status %#x",status);
+        LOG_ERROR("Unexpected intermediate status %#"PRIx32,status);
         return TSS2_TCTI_RC_IO_ERROR;
     }
 
@@ -558,7 +558,7 @@ TSS2_RC tcti_spi_helper_receive (TSS2_TCTI_CONTEXT* tcti_context, size_t *respon
     // Verify that there is no more data available
     status = spi_tpm_helper_read_sts_reg(ctx);
     if ((status & expected_status_bits) != TCTI_SPI_HELPER_TPM_STS_VALID) {
-        LOG_ERROR("Unexpected final status %#x", status);
+        LOG_ERROR("Unexpected final status %#"PRIx32, status);
         return TSS2_TCTI_RC_IO_ERROR;
     }
 
@@ -613,12 +613,20 @@ TSS2_RC tcti_spi_helper_transmit (TSS2_TCTI_CONTEXT *tcti_ctx, size_t size, cons
         return TSS2_TCTI_RC_BAD_VALUE;
     }
 
-    LOGBLOB_DEBUG (cmd_buf, size, "Sending command with TPM_CC %#x and size %" PRIu32,
+    LOGBLOB_DEBUG (cmd_buf, size, "Sending command with TPM_CC %#"PRIx32" and size %" PRIu32,
                header.code, header.size);
 
     // Tell TPM to expect command
     spi_tpm_helper_write_sts_reg(ctx, TCTI_SPI_HELPER_TPM_STS_COMMAND_READY);
 
+    // Wait until ready bit is set by TPM device
+    uint32_t expected_status_bits = TCTI_SPI_HELPER_TPM_STS_COMMAND_READY;
+    rc = spi_tpm_helper_wait_for_status(ctx, expected_status_bits, expected_status_bits, 200);
+    if (rc != TSS2_RC_SUCCESS) {
+        LOG_ERROR("Failed waiting for TPM to become ready");
+        return rc;
+    }
+
     // Send command
     spi_tpm_helper_fifo_transfer(ctx, (void*)cmd_buf, size, TCTI_SPI_HELPER_FIFO_TRANSMIT);
 
@@ -670,11 +678,6 @@ TSS2_RC Tss2_Tcti_Spi_Helper_Init (TSS2_TCTI_CONTEXT* tcti_context, size_t* size
         return TSS2_TCTI_RC_INSUFFICIENT_BUFFER;
     }
 
-    if (!platform_conf) {
-        return TSS2_TCTI_RC_BAD_VALUE;
-    }
-
-
     // Init TCTI context
     TSS2_TCTI_MAGIC (tcti_context) = TCTI_SPI_HELPER_MAGIC;
     TSS2_TCTI_VERSION (tcti_context) = TCTI_VERSION;
